Module bind — Inmanta 2017.4dev documentation

# Module bind

> - License: Apache 2.0
> - Version: 0.4
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/bind.git

## Entities

entity `bind::Server`

  Parents: `dns::Server`

  attribute string `_pkg_name`
  attribute string `_svc_name`
  attribute string `additional_config`=''
  attribute string `axfr_allowed`=''
  attribute string `_zone_dir`
  attribute string `work_dir`

  The following implementations are defined for this entity:

  > - `bind::bindDnsServer`
  > - `bind::bindUbuntu`

  The following implements statements select implementations for this entity:

  > - `bind::bindDnsServer` constraint `std::familyof(host.os,'redhat')`
  > - `bind::bindUbuntu` constraint `std::familyof(host.os,'ubuntu')`

## Implementations

implementation `bind::bindDnsServer`

implementation `bind::bindUbuntu`

implementation `bind::zoneFile`

## Plugins

`bind.` `nameservers`(master_zones: list, slave_zones: list=[]) → list

  Returns a list of all the name servers in ns records in the list of zones

`bind.` `serial`(zone: string, zonefile: string) → string

  This plugin will check if the zonefile has been updated since the last compile. If the zone is update it will replace __SERIAL__ with the current UTC timestamp. If the zonefile has not been updated, it will use the previous serial.

  Parameters: | zone – The name of the zone to check zonefile – The actual zone file. This is a complete and valid zonefile with __SERIAL__ in it as placeholder. This placeholder is replaced with the current serial.